==> SexyMap-v1.8.4.zip: SexyMap/localization/koKR.lua <==

if GetLocale() ~= "koKR" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "1. 배경" -- Needs review
L["2. Border"] = "2. 테두리" -- Needs review
L["3. Artwork"] = "3. 무늬" -- Needs review
L["4. Overlay"] = "4. 덮어씌움" -- Needs review
L["5. Highlight"] = "5. 강조" -- Needs review
L["Add Blend (additive)"] = "기존 무늬에 추가(첨가)"
L["Addon Buttons"] = "애드온 버튼" -- Needs review
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "SexyMap 애드온에서 미니맵 주변으로 버튼을 움직입니다. 이 기능을 끄면 개별 애드온에서 버튼을 이동할 수 있습니다." -- Needs review
L["Alpha Key (1-bit alpha)"] = "투명도 추가 (1비트 알파)"
L["Always"] = "항상 표시" -- Needs review
L["Armored Man"] = "내구도 창" -- Needs review
L["A static amount to rotate the texture by."] = "회전할 무늬의 크기를 조절합니다."
L["Auto Zoom-Out Delay"] = "자동확대 지연시간" -- Needs review
L["Backdrop Color"] = "배경 색상" -- Needs review
L["Backdrop Insets"] = "배경 덧붙임" -- Needs review
L["Background Color"] = "배경 색상" -- Needs review
L["Background/edge"] = "배경/모서리" -- Needs review
L["Background Texture"] = "배경 무늬" -- Needs review
L["Blend Mode"] = "혼합 모드" -- Needs review
L["Blend (normal)"] = "기존 무늬에 합침 (일반)"
L["Border Color"] = "테두리 색상" -- Needs review
L["Border Edge Size"] = "테두리 굵기" -- Needs review
L["Borders"] = "테두리" -- Needs review
L["Border Texture"] = "테두리 무늬" -- Needs review
L["Boss Frames"] = "보스 창" -- Needs review
L["Buttons"] = "버튼" -- Needs review
L["Calendar"] = "달력" -- Needs review
L["Capture Bars"] = "지배 바" -- Needs review
L["Challenge Mode Button (When Available)"] = "도전 모드 버튼 (가능하다면)" -- Needs review
L["Circle"] = "원" -- Needs review
L["Clamp to screen"] = "화면 빠져나감 방지" -- Needs review
L["Clear & start over"] = "초기화 & 새로 시작" -- Needs review
L["Clear the current borders and start fresh"] = "현재 테두리 설정을 초기화 하고 새로 시작합니다." -- Needs review
L["Clock"] = "시계" -- Needs review
L["Coordinates"] = "좌표" -- Needs review
L["Create a new border"] = "새로운 테두리 생성" -- Needs review
L["Current Borders"] = "현재 테두리" -- Needs review
L["Delete"] = "삭제" -- Needs review
L["Diamond"] = "다이아몬드" -- Needs review
L["Disable (opaque)"] = "사용안함(불투명)" -- Needs review
L["Disable Rotation"] = "바꾸기 금지"
L["Drag Radius"] = "미니맵 접근 간격" -- Needs review
L["Dungeon Difficulty Indicator (When Available)"] = "던전 난이도 표시기(가능하다면)" -- Needs review
L["Dynamic Buttons"] = "추가 활성화 버튼" -- Needs review
L["Enable"] = "사용" -- Needs review
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "미니맵에 배경과 테두리를 사용합니다. 가장 쉽게 사각형의 테두리를 적용합니다." -- Needs review
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "HUD 스타일의 미니맵을 사용합니다. 이 기능은 자원 채집시 가장 유용합니다. 다만 기술적인 문제로 미니맵과 동시에 사용은 불가능 합니다. " -- Needs review
L["Enable Coordinates"] = "좌표 사용" -- Needs review
L["Enable Hudmap"] = "Hudmap 사용" -- Needs review
L["Enable Minimap Fader"] = "미니맵 투명도 사용" -- Needs review
L["Enable Movers"] = "이동 프레임 사용" -- Needs review
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "새로운 테두리 생성을 위한 이름을 입력하세요. 가능하면 구분이 가능할 이름을 사용하세요." -- Needs review
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "무늬가 저장되어 있는 전체 경로를 입력하세요. |cffff6600TexBrowser|r와 같은 애드온을 통해서 무늬 선택하는 것을 추천합니다." -- Needs review
L["Entry Options"] = "목록 설정" -- Needs review
L["Faded Circle (Large)"] = "바랜 원 (큼)" -- Needs review
L["Faded Circle (Small)"] = "바랜 원 (작음)" -- Needs review
L["Faded Square"] = "바랜 사각형" -- Needs review
L["Fader"] = "투명도" -- Needs review
L["Font"] = "글꼴" -- Needs review
L["Font Color"] = "글꼴 색상" -- Needs review
L["Font Size"] = "글꼴 크기" -- Needs review
L["Force a square texture. Fixed distortion on square textures."] = "사각형 무늬를 강제로 적용합니다. 사각형 무늬로 왜곡을 수정합니다." -- Needs review
L["GatherMate is a resource gathering helper mod. Installing it allows you to have resource pins on your HudMap."] = "GatherMate는 자원 채집에 도움을 주는 애드온입니다. 이 애드온을 설치하면 HUDmap에 표시됩니다." -- Needs review
L["Guild Dungeon Difficulty Indicator (When Available)"] = "길드 던전 난이도 표시기 (가능하다면)" -- Needs review
L["Heart"] = "하트" -- Needs review
L["Hexagon"] = "육각형" -- Needs review
L["Hide default border"] = "기본 테두리 숨김" -- Needs review
L["Hide the default border on the minimap."] = "블리자드의 미니맵 테두리를 숨깁니다." -- Needs review
L["Horizontal Nudge"] = "좌우로 이동"
L["Horizontal Position"] = "가로 위치" -- Needs review
L["Hover Opacity"] = "올려놓을 때 투명도" -- Needs review
L["HUD Color"] = "HUD 색상" -- Needs review
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds)"] = "미니맵 확대시 자동으로 선택한 시간(초)가 지난 후 원상복귀(축소) 됩니다." -- Needs review
L["Keybinding"] = "단축키" -- Needs review
L["Layer"] = "프레임 높이" -- Needs review
L["Let SexyMap control button visibility"] = "SexyMap 애드온의 버튼 표시 강제 사용" -- Needs review
L["Let SexyMap handle button dragging"] = "SexyMap 애드온의 버튼 움직임 강제 사용" -- Needs review
L["Lock Button Dragging"] = "미니맵 주변 버튼 고정" -- Needs review
L["Lock Coordinates"] = "좌표 고정" -- Needs review
L["Lock Minimap"] = "미니맵 고정" -- Needs review
L["Lock Movers"] = "이동 프레임 고정" -- Needs review
L["Map Button"] = "지도 버튼" -- Needs review
L["Minimap shape"] = "미니맵 모양" -- Needs review
L["Mod Blend (modulative)"] = "모드 조합(조절)" -- Needs review
L["Movers"] = "주변 프레임" -- Needs review
L["Movers Warning"] = "주의 : 이 설정을 공식적으로 지원하는 것이 아닙니다. 임무 추적기의 사라짐, 보스 프레임의 이동 등의 문제점을 야기시킬 수 있습니다. 블리자드에서는 임무추적기와 보스프레임의 이동을 공식적으로는 지원하지 않습니다. 가능하다면 유닛프레임 애드온의 보스 생명력 표시기능을 추천합니다." -- Needs review
L["Name"] = "이름" -- Needs review
L["Never"] = "표시 안함" -- Needs review
L["New Mail Indicator (When Available)"] = "메일 표시기 (가능하다면)" -- Needs review
L["Normal Opacity"] = "기본 투명도" -- Needs review
L["Objectives Tracker"] = "임무창 추적기" -- Needs review
L["Octagon"] = "육각형" -- Needs review
L["On Hover"] = "올려놓을 때 표시" -- Needs review
L["Opacity"] = "투명도" -- Needs review
L["Open TexBrowser"] = "TexBrowser 열기" -- Needs review
L["Ping"] = "핑" -- Needs review
L["Preset"] = "프리셋" -- Needs review
L["Prevent the minimap from being moved off the screen"] = "미니맵을 이동시에 화면 바깥으로 나가는 것을 방지합니다." -- Needs review
L["Profiles"] = "프로필" -- Needs review
L["Queue Status Button (When Available)"] = "대기 시간 버튼 (가능하다면)" -- Needs review
L["Really delete this border?"] = "이 테두리를 삭제하시겠습니까?" -- Needs review
L["Really delete this preset? This can't be undone."] = "현재 구성을 삭제하시겠습니까? 복구가 불가능합니다." -- Needs review
L["Reset Position"] = "위치 초기화" -- Needs review
L["Right Click Configure"] = "오른쪽 버튼 클릭 : 설정" -- Needs review
L["Right clicking the map will open the SexyMap options"] = "지도에서 오른쪽 버튼을 누르면 애드온 설정창을 엽니다." -- Needs review
L["Rotation Speed (seconds)"] = "바꾸기 속도 (초)"
L["Rounded - Bottom Left"] = "둥근 - 왼쪽 아래 사각형" -- Needs review
L["Rounded - Bottom Right"] = "둥근 - 오른쪽 아래 사각형" -- Needs review
L["Rounded - Top Left"] = "둥근 - 왼쪽 위 사각형" -- Needs review
L["Rounded - Top Right"] = "둥근 - 오른쪽 위 사각형" -- Needs review
L["Route 66"] = "루트 66" -- Needs review
L["Routes plots the shortest distance between resource nodes. Install it to show farming routes on your HudMap."] = "Routes는 자원을 채취할 수 있는 가장 단거리를 표시해주는 애드온입니다. 이 애드온을 설치하면 HUDmap에 표시됩니다." -- Needs review
L["Save current settings as preset..."] = "현재 미니맵의 구성을 저장" -- Needs review
L["Scale"] = "크기" -- Needs review
L["Select a preset to load settings from. This will erase any of your current borders."] = "미리 만들어진 설정을 선택합니다. 선택하게 되면 기존의 테두리 설정을 삭제됩니다." -- Needs review
L["Select preset to load"] = "프리셋 선택" -- Needs review
L["SharedMedia Border"] = "SharedMedia 내장 테두리" -- Needs review
L["SharedMedia Texture"] = "SharedMedia 내장 무늬" -- Needs review
L["Show inside chat"] = "대화창에 표시" -- Needs review
L["Show on minimap"] = "미니맵에 표시" -- Needs review
L["Show %s:"] = "%s 표시:" -- Needs review
L["Show who pinged"] = "누가 사용했는지 표시" -- Needs review
L["Snowflake"] = "눈 모양" -- Needs review
L["Square"] = "사각형" -- Needs review
L["Standard Buttons"] = "기본 버튼" -- Needs review
L["Static Rotation"] = "회전 크기"
L["TexBrowser Not Installed"] = "TexBrowser 미설치" -- Needs review
L["Text Color"] = "글자 색상" -- Needs review
L["Texture"] = "무늬" -- Needs review
L["Texture Options"] = "무늬 설정" -- Needs review
L["Texture Path"] = "무늬 경로" -- Needs review
L["Texture Tint"] = "무늬 색조(채도, 명도 포함)" -- Needs review
L["Text Width"] = "글꼴 너비"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "몇 초마다 한 번씩 회전을 합니다. 0초는 회전하지 않습니다."
L["This will wipe out any current settings!"] = "현재 설정이 삭제됩니다." -- Needs review
L["Tile Background"] = "타일식 배경" -- Needs review
L["Tile Size"] = "타일 크기" -- Needs review
L["Tracking Button"] = "추적 버튼" -- Needs review
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "이 기능을 끄면 개별 애드온에서 미니맵 표시 여부를 선택할 수 있습니다." -- Needs review
L["Use GatherMate pins"] = "GatherMate 위치 사용" -- Needs review
L["Use QuestHelper pins"] = "QuestHelper 위치 사용" -- Needs review
L["Use Routes"] = "Routes 애드온 사용" -- Needs review
L["Vehicle Seat"] = "탈것 좌석" -- Needs review
L["Vertical Nudge"] = "상하로 이동"
L["Vertical Position"] = "세로 위치" -- Needs review
L["Video Recording Button (Mac OSX Only, When Available)"] = "비디오 녹화 버튼 (Mac OSX 전용, 가능하다면)" -- Needs review
L["Voice Chat Button (When Available)"] = "음성 대화 버튼 (가능하다면)" -- Needs review
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "미니맵의 배경 및 테두리를 어떤 스타일로도 변경할 수 있습니다. 이 기능은 미니맵의 사각형 스타일 일때 배경을 만드는데 가장 유용합니다." -- Needs review
L["Zone Text"] = "지역 글자" -- Needs review
L["Zoom In Button"] = "축소 버튼" -- Needs review
L["Zoom Out Button"] = "확대 버튼" -- Needs review

==> SexyMap-v2.4.28.zip: SexyMap/localization/koKR.lua <==

if GetLocale() ~= "koKR" then return end
local _, sm = ...
local L = sm.L
L["1. Background"] = "1. 배경" -- Needs review
L["2. Border"] = "2. 테두리" -- Needs review
L["3. Artwork"] = "3. 무늬" -- Needs review
L["4. Overlay"] = "4. 덮어씌움" -- Needs review
L["5. Highlight"] = "5. 강조" -- Needs review
L["Add Blend (additive)"] = "기존 무늬에 추가(첨가)"
L["Addon Buttons"] = "애드온 버튼" -- Needs review
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "공통 프로필이 이미 존재합니다. 프로필을 변경해서 UI를 재시작 할까요?" -- Needs review
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "SexyMap 애드온에서 미니맵 주변으로 버튼을 움직입니다. 이 기능을 끄면 개별 애드온에서 버튼을 이동할 수 있습니다." -- Needs review
L["Alpha Key (1-bit alpha)"] = "투명도 추가 (1비트 알파)"
L["Always"] = "항상 표시" -- Needs review
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "캐릭터별 개별 프로필로 변경할까요? UI를 재시작 해야 합니다." -- Needs review
L["Armored Man"] = "내구도 창" -- Needs review
L["A static amount to rotate the texture by."] = "회전할 무늬의 크기를 조절합니다."
L["Auto Zoom-Out Delay"] = "자동확대 지연시간" -- Needs review
L["Backdrop Color"] = "배경 색상" -- Needs review
L["Backdrop Insets"] = "배경 덧붙임" -- Needs review
L["Background Color"] = "배경 색상" -- Needs review
L["Background/edge"] = "배경/모서리" -- Needs review
L["Background Texture"] = "배경 무늬" -- Needs review
L["Blend Mode"] = "혼합 모드" -- Needs review
L["Blend (normal)"] = "기존 무늬에 합침 (일반)"
L["Border Color"] = "테두리 색상" -- Needs review
L["Border Edge Size"] = "테두리 굵기" -- Needs review
L["Borders"] = "테두리" -- Needs review
L["Border Texture"] = "테두리 무늬" -- Needs review
L["Boss Frames"] = "보스 창" -- Needs review
L["Buttons"] = "버튼" -- Needs review
L["Calendar"] = "달력" -- Needs review
L["Capture Bars"] = "지배 바" -- Needs review
L["Challenge Mode Button (When Available)"] = "도전 모드 버튼 (가능하다면)" -- Needs review
L["Circle"] = "원" -- Needs review
L["Clamp to screen"] = "화면 빠져나감 방지" -- Needs review
L["Clear & start over"] = "초기화 & 새로 시작" -- Needs review
L["Clear the current borders and start fresh"] = "현재 테두리 설정을 초기화 하고 새로 시작합니다." -- Needs review
L["Clock"] = "시계" -- Needs review
L["Coordinates"] = "좌표" -- Needs review
L["Copy a Profile"] = "프로필 복사" -- Needs review
L["Copying this profile will reload your UI, are you sure?"] = "현재 프로필을 복사해서 UI를 재시작 합니다. 확인을 눌러 주세요." -- Needs review
L["Create a new border"] = "새로운 테두리 생성" -- Needs review
L["Current Borders"] = "현재 테두리" -- Needs review
L["Default Presets"] = "기본 프리셋" -- Needs review
L["Delete"] = "삭제" -- Needs review
L["Delete a Profile"] = "프로필 삭제" -- Needs review
L["Diamond"] = "다이아몬드" -- Needs review
L["Disable (opaque)"] = "사용안함(불투명)" -- Needs review
L["Disable Rotation"] = "바꾸기 금지"
L["Drag Radius"] = "미니맵 접근 간격" -- Needs review
L["Dungeon Difficulty Indicator (When Available)"] = "던전 난이도 표시기(가능하다면)" -- Needs review
L["Dynamic Buttons"] = "추가 활성화 버튼" -- Needs review
L["Enable"] = "사용" -- Needs review
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "미니맵에 배경과 테두리를 사용합니다. 가장 쉽게 사각형의 테두리를 적용합니다." -- Needs review
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "HUD 스타일의 미니맵을 사용합니다. 이 기능은 자원 채집시 가장 유용합니다. 다만 기술적인 문제로 미니맵과 동시에 사용은 불가능 합니다. " -- Needs review
L["Enable Coordinates"] = "좌표 사용" -- Needs review
L["Enable Hudmap"] = "Hudmap 사용" -- Needs review
L["Enable Minimap Fader"] = "미니맵 투명도 사용" -- Needs review
L["Enable Movers"] = "이동 프레임 사용" -- Needs review
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "새로운 테두리 생성을 위한 이름을 입력하세요. 가능하면 구분이 가능할 이름을 사용하세요." -- Needs review
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "무늬가 저장되어 있는 전체 경로를 입력하세요. |cffff6600TexBrowser|r와 같은 애드온을 통해서 무늬 선택하는 것을 추천합니다." -- Needs review
L["Entry Options"] = "목록 설정" -- Needs review
L["Faded Circle (Large)"] = "바랜 원 (큼)" -- Needs review
L["Faded Circle (Small)"] = "바랜 원 (작음)" -- Needs review
L["Faded Square"] = "바랜 사각형" -- Needs review
L["Fader"] = "투명도" -- Needs review
L["Font"] = "글꼴" -- Needs review
L["Font Color"] = "글꼴 색상" -- Needs review
L["Font Size"] = "글꼴 크기" -- Needs review
L["Force a square texture. Fixed distortion on square textures."] = "사각형 무늬를 강제로 적용합니다. 사각형 무늬로 왜곡을 수정합니다." -- Needs review
L["Garrison Button (When Available)"] = "주둔지 버튼 (가능하다면)" -- Needs review
L["Guild Dungeon Difficulty Indicator (When Available)"] = "길드 던전 난이도 표시기 (가능하다면)" -- Needs review
L["Heart"] = "하트" -- Needs review
L["Height"] = "높이" -- Needs review
L["Hexagon"] = "육각형" -- Needs review
L["Hide default border"] = "기본 테두리 숨김" -- Needs review
L["Hide the default border on the minimap."] = "블리자드의 미니맵 테두리를 숨깁니다." -- Needs review
L["Horizontal Nudge"] = "좌우로 이동"
L["Horizontal Position"] = "가로 위치" -- Needs review
L["Hover Opacity"] = "올려놓을 때 투명도" -- Needs review
L["HUD Color"] = "HUD 색상" -- Needs review
L["Keybinding"] = "단축키" -- Needs review
L["Layer"] = "프레임 높이" -- Needs review
L["Let SexyMap control button visibility"] = "SexyMap 애드온의 버튼 표시 강제 사용" -- Needs review
L["Let SexyMap handle button dragging"] = "SexyMap 애드온의 버튼 움직임 강제 사용" -- Needs review
L["Lock Button Dragging"] = "미니맵 주변 버튼 고정" -- Needs review
L["Lock Coordinates"] = "좌표 고정" -- Needs review
L["Lock Minimap"] = "미니맵 고정" -- Needs review
L["Lock Movers"] = "이동 프레임 고정" -- Needs review
L["Map Button"] = "지도 버튼" -- Needs review
L["Minimap shape"] = "미니맵 모양" -- Needs review
L["Mod Blend (modulative)"] = "모드 조합(조절)" -- Needs review
L["Movers"] = "주변 프레임" -- Needs review
L["Movers Warning"] = "주의 : 이 설정을 공식적으로 지원하는 것이 아닙니다. 임무 추적기의 사라짐, 보스 프레임의 이동 등의 문제점을 야기시킬 수 있습니다. 블리자드에서는 임무추적기와 보스프레임의 이동을 공식적으로는 지원하지 않습니다. 가능하다면 유닛프레임 애드온의 보스 생명력 표시기능을 추천합니다." -- Needs review
L["Name"] = "이름" -- Needs review
L["Never"] = "표시 안함" -- Needs review
L["New Mail Indicator (When Available)"] = "메일 표시기 (가능하다면)" -- Needs review
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "공통 프로필이 없습니다. 현재 캐릭터의 프로필이 복사되어 사용됩니다. UI를 재시작 해야 합니다." -- Needs review
L["Normal Opacity"] = "기본 투명도" -- Needs review
L["Objectives Tracker"] = "임무창 추적기" -- Needs review
L["Octagon"] = "육각형" -- Needs review
L["On Hover"] = "올려놓을 때 표시" -- Needs review
L["Opacity"] = "투명도" -- Needs review
L["Open TexBrowser"] = "TexBrowser 열기" -- Needs review
L["Ping"] = "핑" -- Needs review
L["Preset"] = "프리셋" -- Needs review
L["Prevent the minimap from being moved off the screen"] = "미니맵을 이동시에 화면 바깥으로 나가는 것을 방지합니다." -- Needs review
L["Profiles"] = "프로필" -- Needs review
L["Queue Status (PvP/LFG) Button (When Available)"] = "대기 상태 (전장/파티찾기) 버튼 (가능하다면)" -- Needs review
L["Quickly change the look of your minimap by using a minimap preset."] = "미니맵 프리셋으로 미니맵의 모양을 빠르게 바꿀 수 있습니다." -- Needs review
L["Really delete this border?"] = "이 테두리를 삭제하시겠습니까?" -- Needs review
L["Really delete this preset? This can't be undone."] = "현재 구성을 삭제하시겠습니까? 복구가 불가능합니다." -- Needs review
L["Really delete this profile?"] = "현재 프로필을 삭제하시겠습니까?" -- Needs review
L["(Requires button visibility control in the Buttons menu)"] = "(버튼 메뉴에서 표시 요구시)" -- Needs review
L["Reset Current Profile"] = "현재 프로필 초기화" -- Needs review
L["Reset Position"] = "위치 초기화" -- Needs review
L["Resetting this profile will reload your UI, are you sure?"] = "현재 프로필을 초기화하여 UI를 재시작합니다. 확인을 눌러 주세요." -- Needs review
L["Right Click Configure"] = "오른쪽 버튼 클릭 : 설정" -- Needs review
L["Right clicking the map will open the SexyMap options"] = "지도에서 오른쪽 버튼을 누르면 애드온 설정창을 엽니다." -- Needs review
L["Rotation Speed (seconds)"] = "바꾸기 속도 (초)"
L["Rounded - Bottom Left"] = "둥근 - 왼쪽 아래 사각형" -- Needs review
L["Rounded - Bottom Right"] = "둥근 - 오른쪽 아래 사각형" -- Needs review
L["Rounded - Top Left"] = "둥근 - 왼쪽 위 사각형" -- Needs review
L["Rounded - Top Right"] = "둥근 - 오른쪽 위 사각형" -- Needs review
L["Route 66"] = "루트 66" -- Needs review
L["Save current settings as preset..."] = "현재 미니맵의 구성을 저장" -- Needs review
L["Scale"] = "크기" -- Needs review
L["Select a preset to load settings from. This will erase any of your current borders."] = "미리 만들어진 설정을 선택합니다. 선택하게 되면 기존의 테두리 설정을 삭제됩니다." -- Needs review
L["Select preset to load"] = "프리셋 선택" -- Needs review
L["SharedMedia Border"] = "SharedMedia 내장 테두리" -- Needs review
L["SharedMedia Texture"] = "SharedMedia 내장 무늬" -- Needs review
L["Show inside chat"] = "대화창에 표시" -- Needs review
L["Show North Tag"] = "북쪽 'N' 마크 표시" -- Needs review
L["Show on minimap"] = "미니맵에 표시" -- Needs review
L["Show %s:"] = "%s 표시:" -- Needs review
L["Show who pinged"] = "누가 사용했는지 표시" -- Needs review
L["Snowflake"] = "눈 모양" -- Needs review
L["Spice up your minimap with some sexy options."] = "미니맵에 다양한 기능을 부가합니다." -- Needs review
L["Square"] = "사각형" -- Needs review
L["Standard Buttons"] = "기본 버튼" -- Needs review
L["Static Rotation"] = "회전 크기"
L["TexBrowser Not Installed"] = "TexBrowser 미설치" -- Needs review
L["Text Color"] = "글자 색상" -- Needs review
L["Texture"] = "무늬" -- Needs review
L["Texture Options"] = "무늬 설정" -- Needs review
L["Texture Path"] = "무늬 경로" -- Needs review
L["Texture Tint"] = "무늬 색조(채도, 명도 포함)" -- Needs review
L["Text Width"] = "글꼴 너비"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "HudMap의 기능을 지원합니다. 이 애드온이 설치되어 있다면 HudMap을 표시할 것입니다." -- Needs review
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "몇 초마다 한 번씩 회전을 합니다. 0초는 회전하지 않습니다."
L["This will wipe out any current settings!"] = "현재 설정이 삭제됩니다." -- Needs review
L["Tile Background"] = "타일식 배경" -- Needs review
L["Tile Size"] = "타일 크기" -- Needs review
L["Toggle HudMap On/Off"] = "HudMap 켜기/끄기 전환" -- Needs review
L["Tracking Button"] = "추적 버튼" -- Needs review
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "이 기능을 끄면 개별 애드온에서 미니맵 표시 여부를 선택할 수 있습니다." -- Needs review
L["Use Global Profile"] = "공통 프로필 사용" -- Needs review
L["User-Submitted Presets"] = "추천 프리셋" -- Needs review
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "모든 캐릭터를 동일하게 설정하고자 하면 공통 프로필을 사용하세요. 개별 프로필은 각각 다른 형태로 설정이 가능합니다." -- Needs review
L["Vehicle Seat"] = "탈것 좌석" -- Needs review
L["Vertical Nudge"] = "상하로 이동"
L["Vertical Position"] = "세로 위치" -- Needs review
L["Video Recording Button (Mac OSX Only, When Available)"] = "비디오 녹화 버튼 (Mac OSX 전용, 가능하다면)" -- Needs review
L["Visibility"] = "보임" -- Needs review
L["Voice Chat Button (When Available)"] = "음성 대화 버튼 (가능하다면)" -- Needs review
L["Width"] = "너비" -- Needs review
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "미니맵의 배경 및 테두리를 어떤 스타일로도 변경할 수 있습니다. 이 기능은 미니맵의 사각형 스타일 일때 배경을 만드는데 가장 유용합니다." -- Needs review
L["Zone Text"] = "지역 글자" -- Needs review
L["Zoom In Button"] = "축소 버튼" -- Needs review
L["Zoom Out Button"] = "확대 버튼" -- Needs review
